Learn R Programming

ZeligEI (version 0.1-2)

Zelig-ei-class: Ecological Inference object for inheritance across models in ZeligEI

Description

Ecological Inference object for inheritance across models in ZeligEI

Arguments

Methods

getcoef()

Get estimated model coefficients

zelig(formula, data, model = NULL, ..., weights = NULL, by, bootstrap = FALSE)

The zelig function estimates a variety of statistical models