Learn R Programming

ZeligEI (version 0.1-2)

convertEIformula: Conversion utility to allow different possible formula notations, and deal with zeroes and missing values, for EI models in eiheir, eidynamic

Description

Conversion utility to allow different possible formula notations, and deal with zeroes and missing values, for EI models in eiheir, eidynamic

Usage

convertEIformula(formula, N, data, na.action)

Arguments