powered by
Ecological Inference object for inheritance across models in ZeligEI
getcoef()
Get estimated model coefficients
zelig(formula, data, model = NULL, ..., weights = NULL, by, bootstrap = FALSE)
The zelig function estimates a variety of statistical models