convertEIformula2: Conversion utility to allow different possible formula notations, and deal with zeroes and missing values, for EI models in eiml, eirxc
Description
Conversion utility to allow different possible formula notations, and deal with zeroes and missing values, for EI models in eiml, eirxc
Usage
convertEIformula2(formula, data, N, na.action, rxc = FALSE)